@@ -8,64 +8,67 @@ from .. import convert, equilibria, salts, solve, uncertainty
 
 # Define function input keys that should be converted to floats
 input_floats = {
+    "fugacity_factor_out",
+    "fugacity_factor",
+    "gas_constant_out",
+    "gas_constant",
+    "k_ammonia_out",
+    "k_ammonia",
+    "k_aragonite_out",
+    "k_aragonite",
+    "k_bisulfate_out",
+    "k_bisulfate",
+    "k_borate_out",
+    "k_borate",
+    "k_calcite_out",
+    "k_calcite",
+    "k_carbonic_1_out",
+    "k_carbonic_1",
+    "k_carbonic_2_out",
+    "k_carbonic_2",
+    "k_CO2_out",
+    "k_CO2",
+    "k_fluoride_out",
+    "k_fluoride",
+    "k_phosphoric_1_out",
+    "k_phosphoric_1",
+    "k_phosphoric_2_out",
+    "k_phosphoric_2",
+    "k_phosphoric_3_out",
+    "k_phosphoric_3",
+    "k_silicate_out",
+    "k_silicate",
+    "k_sulfide_out",
+    "k_sulfide",
+    "k_water_out",
+    "k_water",
     "par1",
     "par2",
-    "salinity",
-    "temperature",
-    "temperature_out",
-    "pressure",
     "pressure_out",
+    "pressure",
+    "salinity",
+    "temperature_out",
+    "temperature",
     "total_ammonia",
-    "total_phosphate",
-    "total_silicate",
-    "total_sulfide",
     "total_borate",
     "total_calcium",
     "total_fluoride",
+    "total_phosphate",
+    "total_silicate",
     "total_sulfate",
-    "k_ammonia",
-    "k_ammonia_out",
-    "k_borate",
-    "k_borate_out",
-    "k_bisulfate",
-    "k_bisulfate_out",
-    "k_CO2",
-    "k_CO2_out",
-    "k_carbonic_1",
-    "k_carbonic_1_out",
-    "k_carbonic_2",
-    "k_carbonic_2_out",
-    "k_fluoride",
-    "k_fluoride_out",
-    "k_phosphoric_1",
-    "k_phosphoric_1_out",
-    "k_phosphoric_2",
-    "k_phosphoric_2_out",
-    "k_phosphoric_3",
-    "k_phosphoric_3_out",
-    "k_silicate",
-    "k_silicate_out",
-    "k_sulfide",
-    "k_sulfide_out",
-    "k_water",
-    "k_water_out",
-    "k_calcite",
-    "k_calcite_out",
-    "k_aragonite",
-    "k_aragonite_out",
-    "fugacity_factor",
-    "fugacity_factor_out",
-    "vp_factor",
+    "total_sulfide",
     "vp_factor_out",
-    "gas_constant",
-    "gas_constant_out",
+    "vp_factor",
     # Added in v1.6.0:
-    "total_alpha",
-    "k_alpha",
     "k_alpha_out",
-    "total_beta",
-    "k_beta",
+    "k_alpha",
     "k_beta_out",
+    "k_beta",
+    "total_alpha",
+    "total_beta",
+    # Added in v1.8.0:
+    "pressure_atmosphere_out",
+    "pressure_atmosphere",
 }
 
 
@@ -107,7 +110,14 @@ def condition(args, to_shape=None):
         # Broadcast the non-scalar args to a consistent shape
         args_conditioned = {
             k: np.broadcast_to(v, args_broadcast_shape)
-            if k in ["par1", "par2", "par1_type", "par2_type",] or not np.isscalar(v)
+            if k
+            in [
+                "par1",
+                "par2",
+                "par1_type",
+                "par2_type",
+            ]
+            or not np.isscalar(v)
             else v
             for k, v in args.items()
         }
@@ -243,7 +253,10 @@ def _get_results_dict(
     results = {}
     if core_in is not None:
         results.update(
-            {"par1": args["par1"], "par1_type": args["par1_type"],}
+            {
+                "par1": args["par1"],
+                "par1_type": args["par1_type"],
+            }
         )
         if "TA" in core_in and "TC" in core_in:
             results.update(
@@ -279,6 +292,9 @@ def _get_results_dict(
             # Added in v1.6.0:
             "total_alpha": totals["total_alpha"] * 1e6,
             "total_beta": totals["total_beta"] * 1e6,
+            # Added in v1.8.0:
+            "pressure_atmosphere": args["pressure_atmosphere"],
+            "pressure_atmosphere_out": args["pressure_atmosphere_out"],
         }
     )
     results.update(_get_in_out(core_in, others_in, k_constants_in, suffix=""))
@@ -297,11 +313,109 @@ def _get_results_dict(
 
 # Define list of gradable output keys
 gradables = [
+    "alkalinity_ammonia_out",
+    "alkalinity_ammonia",
+    "alkalinity_borate_out",
+    "alkalinity_borate",
+    "alkalinity_phosphate_out",
+    "alkalinity_phosphate",
+    "alkalinity_silicate_out",
+    "alkalinity_silicate",
+    "alkalinity_sulfide_out",
+    "alkalinity_sulfide",
+    "alkalinity",
+    "aqueous_CO2_out",
+    "aqueous_CO2",
+    "beta_alk_out",
+    "beta_alk",
+    "beta_dic_out",
+    "beta_dic",
+    "bicarbonate_out",
+    "bicarbonate",
+    "carbonate_out",
+    "carbonate",
+    "dic",
+    "fCO2_out",
+    "fCO2",
+    "fH_out",
+    "fH",
+    "fugacity_factor_out",
+    "fugacity_factor",
+    "gamma_alk_out",
+    "gamma_alk",
+    "gamma_dic_out",
+    "gamma_dic",
+    "gas_constant",
+    "hydrogen_free_out",
+    "hydrogen_free",
+    "hydroxide_out",
+    "hydroxide",
+    "isocapnic_quotient_approx_out",
+    "isocapnic_quotient_approx",
+    "isocapnic_quotient_out",
+    "isocapnic_quotient",
+    "k_ammonia_out",
+    "k_ammonia",
+    "k_aragonite_out",
+    "k_aragonite",
+    "k_bisulfate_out",
+    "k_bisulfate",
+    "k_borate_out",
+    "k_borate",
+    "k_calcite_out",
+    "k_calcite",
+    "k_carbonic_1_out",
+    "k_carbonic_1",
+    "k_carbonic_2_out",
+    "k_carbonic_2",
+    "k_CO2_out",
+    "k_CO2",
+    "k_fluoride_out",
+    "k_fluoride",
+    "k_phosphoric_1_out",
+    "k_phosphoric_1",
+    "k_phosphoric_2_out",
+    "k_phosphoric_2",
+    "k_phosphoric_3_out",
+    "k_phosphoric_3",
+    "k_silicate_out",
+    "k_silicate",
+    "k_sulfide_out",
+    "k_sulfide",
+    "k_water_out",
+    "k_water",
+    "omega_alk_out",
+    "omega_alk",
+    "omega_dic_out",
+    "omega_dic",
     "par1",
     "par2",
-    "salinity",
-    "temperature",
+    "pCO2_out",
+    "pCO2",
+    "peng_correction",
+    "pH_free_out",
+    "pH_free",
+    "pH_nbs_out",
+    "pH_nbs",
+    "pH_out",
+    "pH_sws_out",
+    "pH_sws",
+    "pH_total_out",
+    "pH_total",
+    "pH",
     "pressure",
+    "psi_out",
+    "psi",
+    "revelle_factor_out",
+    "revelle_factor",
+    "salinity",
+    "saturation_aragonite_out",
+    "saturation_aragonite",
+    "saturation_calcite_out",
+    "saturation_calcite",
+    "substrate_inhibitor_ratio_out",
+    "substrate_inhibitor_ratio",
+    "temperature",
     "total_ammonia",
     "total_borate",
     "total_calcium",
@@ -310,141 +424,46 @@ gradables = [
     "total_silicate",
     "total_sulfate",
     "total_sulfide",
-    "peng_correction",
-    "gas_constant",
-    "alkalinity",
-    "dic",
-    "pH",
-    "pH_out",
-    "pCO2",
-    "pCO2_out",
-    "fCO2",
-    "fCO2_out",
-    "bicarbonate",
-    "bicarbonate_out",
-    "carbonate",
-    "carbonate_out",
-    "aqueous_CO2",
-    "aqueous_CO2_out",
-    "alkalinity_borate",
-    "alkalinity_borate_out",
-    "hydroxide",
-    "hydroxide_out",
-    "alkalinity_phosphate",
-    "alkalinity_phosphate_out",
-    "alkalinity_silicate",
-    "alkalinity_silicate_out",
-    "alkalinity_ammonia",
-    "alkalinity_ammonia_out",
-    "alkalinity_sulfide",
-    "alkalinity_sulfide_out",
-    "hydrogen_free",
-    "hydrogen_free_out",
-    "revelle_factor",
-    "revelle_factor_out",
-    "saturation_calcite",
-    "saturation_calcite_out",
-    "saturation_aragonite",
-    "saturation_aragonite_out",
-    "xCO2",
     "xCO2_out",
-    "pH_total",
-    "pH_total_out",
-    "pH_sws",
-    "pH_sws_out",
-    "pH_free",
-    "pH_free_out",
-    "pH_nbs",
-    "pH_nbs_out",
-    "k_CO2",
-    "k_CO2_out",
-    "k_carbonic_1",
-    "k_carbonic_1_out",
-    "k_carbonic_2",
-    "k_carbonic_2_out",
-    "k_water",
-    "k_water_out",
-    "k_borate",
-    "k_borate_out",
-    "k_bisulfate",
-    "k_bisulfate_out",
-    "k_fluoride",
-    "k_fluoride_out",
-    "k_phosphoric_1",
-    "k_phosphoric_1_out",
-    "k_phosphoric_2",
-    "k_phosphoric_2_out",
-    "k_phosphoric_3",
-    "k_phosphoric_3_out",
-    "k_silicate",
-    "k_silicate_out",
-    "k_ammonia",
-    "k_ammonia_out",
-    "k_sulfide",
-    "k_sulfide_out",
-    "k_calcite",
-    "k_calcite_out",
-    "k_aragonite",
-    "k_aragonite_out",
-    "gamma_dic",
-    "gamma_dic_out",
-    "beta_dic",
-    "beta_dic_out",
-    "omega_dic",
-    "omega_dic_out",
-    "gamma_alk",
-    "gamma_alk_out",
-    "beta_alk",
-    "beta_alk_out",
-    "omega_alk",
-    "omega_alk_out",
-    "isocapnic_quotient",
-    "isocapnic_quotient_out",
-    "isocapnic_quotient_approx",
-    "isocapnic_quotient_approx_out",
-    "psi",
-    "psi_out",
-    "substrate_inhibitor_ratio",
-    "substrate_inhibitor_ratio_out",
-    "fugacity_factor",
-    "fugacity_factor_out",
-    "fH",
-    "fH_out",
+    "xCO2",
     # Added in v1.6.0:
-    "total_alpha",
-    "k_alpha",
-    "k_alpha_out",
-    "total_beta",
-    "k_beta",
-    "k_beta_out",
-    "HCO3",
-    "CO3",
-    "CO2",
-    "BOH4",
-    "BOH3",
-    "OH",
-    "Hfree",
-    "H3PO4",
-    "H2PO4",
-    "HPO4",
-    "PO4",
-    "H3SiO4",
-    "H4SiO4",
-    "NH3",
-    "NH4",
-    "HS",
-    "H2S",
-    "HSO4",
-    "SO4",
-    "HF",
-    "F",
     "alpha",
     "alphaH",
     "beta",
     "betaH",
+    "BOH3",
+    "BOH4",
+    "CO2",
+    "CO3",
+    "F",
+    "H2PO4",
+    "H2S",
+    "H3PO4",
+    "H3SiO4",
+    "H4SiO4",
+    "HCO3",
+    "HF",
+    "Hfree",
+    "HPO4",
+    "HS",
+    "HSO4",
+    "k_alpha_out",
+    "k_alpha",
+    "k_beta_out",
+    "k_beta",
+    "NH3",
+    "NH4",
+    "OH",
+    "PO4",
+    "SO4",
+    "total_alpha",
+    "total_beta",
     # Added in v1.7.0:
-    "vp_factor",
     "vp_factor_out",
+    "vp_factor",
+    # Added in v1.8.0:
+    "pressure_atmosphere_out",
+    "pressure_atmosphere",
 ]
 
 
@@ -521,6 +540,9 @@ def CO2SYS(
     grads_wrt=None,
     uncertainty_into=None,
     uncertainty_from=None,
+    # Added in v1.8.0:
+    pressure_atmosphere=1.0,  # atm
+    pressure_atmosphere_out=1.0,  # atm
 ):
     """Run CO2SYS with n-dimensional args allowed."""
     args = locals()
@@ -598,6 +620,7 @@ def CO2SYS(
         args["opt_k_fluoride"],
         args["opt_gas_constant"],
         Ks=k_constants_in,
+        pressure_atmosphere=args["pressure_atmosphere"],
     )
     # Solve the core marine carbonate system at input conditions, if provided
     if par1 is not None:
@@ -637,7 +660,12 @@ def CO2SYS(
                 core_in["PH"], args["opt_pH_scale"], totals, k_constants_in
             )
             others_in.update(
-                {"pHT": pH_total, "pHS": pH_sws, "pHF": pH_free, "pHN": pH_nbs,}
+                {
+                    "pHT": pH_total,
+                    "pHS": pH_sws,
+                    "pHF": pH_free,
+                    "pHN": pH_nbs,
+                }
             )
         # One of pCO2, fCO2, CO2(aq) or xCO2 only
         if np.any(np.isin(args["par1_type"], [4, 5, 8, 9])):
@@ -677,7 +705,12 @@ def CO2SYS(
                 convert.fCO2_to_xCO2(fCO2, k_constants_in),
             )
             core_in.update(
-                {"PC": pCO2, "FC": fCO2, "CO2": CO2aq, "XC": xCO2,}
+                {
+                    "PC": pCO2,
+                    "FC": fCO2,
+                    "CO2": CO2aq,
+                    "XC": xCO2,
+                }
             )
     else:
         core_in = None
@@ -713,6 +746,7 @@ def CO2SYS(
             args["opt_k_fluoride"],
             args["opt_gas_constant"],
             Ks=k_constants_out,
+            pressure_atmosphere=args["pressure_atmosphere_out"],
         )
         # Solve the core marine carbonate system at output conditions, if requested
         if par1 is not None and par2 is not None:
@@ -900,4 +934,5 @@ def assemble(
         args["opt_k_fluoride"],
         args["opt_gas_constant"],
         Ks=k_constants,
+        pressure_atmosphere=args["pressure_atmosphere"],
     )
